@@ -4,7 +4,7 @@
 from __future__ import annotations
 
 import os
-import typing as t
+from collections.abc import Iterator
 from contextlib import contextmanager, nullcontext, suppress
 from functools import partial
 from pathlib import Path
@@ -12,6 +12,7 @@ from shutil import copytree
 from sys import implementation as _system_implementation
 from sys import stderr as _standard_error_stream
 from tempfile import TemporaryDirectory
+from typing import Union
 from warnings import warn as _warn_that
 
 from setuptools.build_meta import build_sdist as _setuptools_build_sdist
@@ -42,14 +43,12 @@ with suppress(ImportError):
     from Cython.Build.Cythonize import main as _cythonize_cli_cmd
 
 from ._compat import chdir_cm
-from ._cython_configuration import (  # noqa: WPS436
-    get_local_cython_config as _get_local_cython_config,
-)
+from ._cython_configuration import get_local_cython_config as _get_local_cython_config
 from ._cython_configuration import (
     make_cythonize_cli_args_from_config as _make_cythonize_cli_args_from_config,
 )
 from ._cython_configuration import patched_env as _patched_cython_env
-from ._transformers import sanitize_rst_roles  # noqa: WPS436
+from ._transformers import sanitize_rst_roles
 
 __all__ = (  # noqa: WPS410
     'build_sdist',
@@ -57,7 +56,7 @@ __all__ = (  # noqa: WPS410
     'get_requires_for_build_wheel',
     'prepare_metadata_for_build_wheel',
     *(
-        () if _setuptools_build_editable is None
+        () if _setuptools_build_editable is None  # type: ignore[redundant-expr]
         else (
             'build_editable',
             'get_requires_for_build_editable',
@@ -66,7 +65,7 @@ __all__ = (  # noqa: WPS410
     ),
 )
 
-_ConfigDict = t.Dict[str, t.Union[str, t.List[str], None]]
+_ConfigDict = dict[str, Union[str, list[str], None]]
 
 
 CYTHON_TRACING_CONFIG_SETTING = 'with-cython-tracing'
@@ -88,7 +87,7 @@ PURE_PYTHON_MODE_CLI_FALLBACK = not IS_CPYTHON
 """A fallback for ``pure-python`` is not set."""
 
 
-def _is_truthy_setting_value(setting_value) -> bool:
+def _is_truthy_setting_value(setting_value: str) -> bool:
     truthy_values = {'', None, 'true', '1', 'on'}
     return setting_value.lower() in truthy_values
 
@@ -109,7 +108,7 @@ def _get_setting_value(
             continue
 
         with suppress(lookup_errors):  # type: ignore[arg-type]
-            return _is_truthy_setting_value(src_mapping[src_key])  # type: ignore[index]
+            return _is_truthy_setting_value(src_mapping[src_key])  # type: ignore[arg-type,index]
 
     return default
 
@@ -126,7 +125,7 @@ def _make_pure_python(config_settings: _ConfigDict | None = None) -> bool:
 def _include_cython_line_tracing(
         config_settings: _ConfigDict | None = None,
         *,
-        default=False,
+        default: bool = False,
 ) -> bool:
     return _get_setting_value(
         config_settings,
@@ -137,7 +136,7 @@ def _include_cython_line_tracing(
 
 
 @contextmanager
-def patched_distutils_cmd_install():
+def patched_distutils_cmd_install() -> Iterator[None]:
     """Make `install_lib` of `install` cmd always use `platlib`.
 
     :yields: None
@@ -145,19 +144,19 @@ def patched_distutils_cmd_install():
     # Without this, build_lib puts stuff under `*.data/purelib/` folder
     orig_finalize = _distutils_install_cmd.finalize_options
 
-    def new_finalize_options(self):  # noqa: WPS430
+    def new_finalize_options(self: _distutils_install_cmd) -> None:
         self.install_lib = self.install_platlib
         orig_finalize(self)
 
-    _distutils_install_cmd.finalize_options = new_finalize_options
+    _distutils_install_cmd.finalize_options = new_finalize_options  # type: ignore[method-assign]
     try:
         yield
     finally:
-        _distutils_install_cmd.finalize_options = orig_finalize
+        _distutils_install_cmd.finalize_options = orig_finalize  # type: ignore[method-assign]
 
 
 @contextmanager
-def patched_dist_has_ext_modules():
+def patched_dist_has_ext_modules() -> Iterator[None]:
     """Make `has_ext_modules` of `Distribution` always return `True`.
 
     :yields: None
@@ -165,15 +164,15 @@ def patched_dist_has_ext_modules():
     # Without this, build_lib puts stuff under `*.data/platlib/` folder
     orig_func = _DistutilsDistribution.has_ext_modules
 
-    _DistutilsDistribution.has_ext_modules = lambda *args, **kwargs: True
+    _DistutilsDistribution.has_ext_modules = lambda *args, **kwargs: True  # type: ignore[method-assign]
     try:
         yield
     finally:
-        _DistutilsDistribution.has_ext_modules = orig_func
+        _DistutilsDistribution.has_ext_modules = orig_func  # type: ignore[method-assign]
 
 
 @contextmanager
-def patched_dist_get_long_description():
+def patched_dist_get_long_description() -> Iterator[None]:
     """Make `has_ext_modules` of `Distribution` always return `True`.
 
     :yields: None
@@ -181,16 +180,17 @@ def patched_dist_get_long_description():
     # Without this, build_lib puts stuff under `*.data/platlib/` folder
     _orig_func = _DistutilsDistributionMetadata.get_long_description
 
-    def _get_sanitized_long_description(self):
+    def _get_sanitized_long_description(self: _DistutilsDistributionMetadata) -> str:
+        assert self.long_description is not None
         return sanitize_rst_roles(self.long_description)
 
-    _DistutilsDistributionMetadata.get_long_description = (
+    _DistutilsDistributionMetadata.get_long_description = (  # type: ignore[method-assign]
         _get_sanitized_long_description
     )
     try:
         yield
     finally:
-        _DistutilsDistributionMetadata.get_long_description = _orig_func
+        _DistutilsDistributionMetadata.get_long_description = _orig_func  # type: ignore[method-assign]
 
 
 def _exclude_dir_path(
@@ -217,7 +217,7 @@ def _exclude_dir_path(
 
 
 @contextmanager
-def _in_temporary_directory(src_dir: Path) -> t.Iterator[None]:
+def _in_temporary_directory(src_dir: Path) -> Iterator[None]:
     with TemporaryDirectory(prefix='.tmp-yarl-pep517-') as tmp_dir:
         tmp_dir_path = Path(tmp_dir)
         root_tmp_dir_path = tmp_dir_path.parent
@@ -240,7 +240,7 @@ def maybe_prebuild_c_extensions(
         line_trace_cython_when_unset: bool = False,
         build_inplace: bool = False,
         config_settings: _ConfigDict | None = None,
-) -> t.Generator[None, t.Any, t.Any]:
+) -> Iterator[None]:
     """Pre-build C-extensions in a temporary directory, when needed.
 
     This context manager also patches metadata, setuptools and distutils.
@@ -294,7 +294,7 @@ def maybe_prebuild_c_extensions(
 
         cythonize_args = _make_cythonize_cli_args_from_config(config)
         with _patched_cython_env(config['env'], cython_line_tracing_requested):
-            _cythonize_cli_cmd(cythonize_args)
+            _cythonize_cli_cmd(cythonize_args)  # type: ignore[no-untyped-call]
         with patched_distutils_cmd_install():
             with patched_dist_has_ext_modules():
                 yield
@@ -302,9 +302,9 @@ def maybe_prebuild_c_extensions(
 
 @patched_dist_get_long_description()
 def build_wheel(
-        wheel_directory: str,
-        config_settings: _ConfigDict | None = None,
-        metadata_directory: str | None = None,
+    wheel_directory: str,
+    config_settings: _ConfigDict | None = None,
+    metadata_directory: str | None = None,
 ) -> str:
     """Produce a built wheel.
 
@@ -329,9 +329,9 @@ def build_wheel(
 
 @patched_dist_get_long_description()
 def build_editable(
-        wheel_directory: str,
-        config_settings: _ConfigDict | None = None,
-        metadata_directory: str | None = None,
+    wheel_directory: str,
+    config_settings: _ConfigDict | None = None,
+    metadata_directory: str | None = None,
 ) -> str:
     """Produce a built wheel for editable installs.
 
@@ -355,7 +355,7 @@ def build_editable(
 
 
 def get_requires_for_build_wheel(
-        config_settings: _ConfigDict | None = None,
+    config_settings: _ConfigDict | None = None,
 ) -> list[str]:
     """Determine additional requirements for building wheels.
 
